=== modified file '.bzrignore'
--- .bzrignore	2011-11-05 03:32:21 +0000
+++ .bzrignore	2011-11-18 02:03:41 +0000
@@ -379,3 +379,4 @@
 plugin/innobase/xtrabackup/drizzlebackup.innobase
 libdrizzle-2.0/drizzle_password_hash
 libdrizzle-2.0/mysql_password_hash
+tags

=== modified file 'libdrizzle-2.0/column.cc'
--- libdrizzle-2.0/column.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/column.cc	2011-11-18 16:11:02 +0000
@@ -354,28 +354,38 @@
 drizzle_column_st *drizzle_column_create(drizzle_result_st *result,
                                          drizzle_column_st *column)
 {
+  if (result == NULL)
+  {
+    return NULL;
+  }
+
   if (column == NULL)
   {
-    column= new drizzle_column_st;
-    column->result = result;
+    column= new (std::nothrow) drizzle_column_st;
+
+    if (column == NULL)
+    {
+      return NULL;
+    }
+
+    column->result= result;
     /* SET BELOW: column->next */
-    column->prev = NULL;
+    column->prev= NULL;
     column->options= DRIZZLE_COLUMN_ALLOCATED;
-    column->catalog[0] = '\0';
-    column->db[0] = '\0';
-    column->table[0] = '\0';
-    column->orig_table[0] = '\0';
-    column->name[0] = '\0';
-    column->orig_name[0] = '\0';
-    column->charset = 0;
-    column->size = 0;
-    column->max_size = 0;
-    column->type = static_cast<drizzle_column_type_t>(0);
-    column->flags = drizzle_column_flags_t();
-    column->decimals = 0;
+    column->catalog[0]= '\0';
+    column->schema[0]= '\0';
+    column->table[0]= '\0';
+    column->orig_table[0]= '\0';
+    column->name[0]= '\0';
+    column->orig_name[0]= '\0';
+    column->charset= 0;
+    column->size= 0;
+    column->max_size= 0;
+    column->type= static_cast<drizzle_column_type_t>(0);
+    column->flags= drizzle_column_flags_t();
+    column->decimals= 0;
     /* UNSET: column->default_value */
-    column->default_value_size = 0;
-
+    column->default_value_size= 0;
   }
   else
   {
@@ -384,7 +394,7 @@
     column->prev = NULL;
     column->options= drizzle_column_options_t();
     column->catalog[0] = '\0';
-    column->db[0] = '\0';
+    column->schema[0] = '\0';
     column->table[0] = '\0';
     column->orig_table[0] = '\0';
     column->name[0] = '\0';
@@ -411,90 +421,184 @@
 
 void drizzle_column_free(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (column->result->column_list == column)
+  {
     column->result->column_list= column->next;
+  }
+
   if (column->prev)
+  {
     column->prev->next= column->next;
+  }
+
   if (column->next)
+  {
     column->next->prev= column->prev;
+  }
 
   if (column->options & DRIZZLE_COLUMN_ALLOCATED)
+  {
     delete column;
+  }
 }
 
 drizzle_result_st *drizzle_column_drizzle_result(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->result;
 }
 
 const char *drizzle_column_catalog(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->catalog;
 }
 
+const char *drizzle_column_shema(drizzle_column_st *column)
+{
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
+  return column->schema;
+}
+
 const char *drizzle_column_db(drizzle_column_st *column)
 {
-  return column->db;
+  return drizzle_column_shema(column);
 }
 
 const char *drizzle_column_table(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->table;
 }
 
 const char *drizzle_column_orig_table(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->orig_table;
 }
 
 const char *drizzle_column_name(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->name;
 }
 
 const char *drizzle_column_orig_name(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return NULL;
+  }
+
   return column->orig_name;
 }
 
 drizzle_charset_t drizzle_column_charset(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->charset;
 }
 
 uint32_t drizzle_column_size(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->size;
 }
 
 size_t drizzle_column_max_size(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->max_size;
 }
 
 void drizzle_column_set_max_size(drizzle_column_st *column, size_t size)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->max_size= size;
 }
 
 drizzle_column_type_t drizzle_column_type(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return drizzle_column_type_t();
+  }
+
   return column->type;
 }
 
-drizzle_column_type_drizzle_t
-drizzle_column_type_drizzle(drizzle_column_st *column)
+drizzle_column_type_drizzle_t drizzle_column_type_drizzle(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return drizzle_column_type_drizzle_t();
+  }
+
   return _column_type_drizzle_map_from[column->type];
 }
 
 int drizzle_column_flags(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->flags;
 }
 
 uint8_t drizzle_column_decimals(drizzle_column_st *column)
 {
+  if (column == NULL)
+  {
+    return 0;
+  }
+
   return column->decimals;
 }
 
@@ -511,7 +615,11 @@
 
 drizzle_return_t drizzle_column_skip(drizzle_result_st *result)
 {
-  drizzle_return_t ret;
+  if (result == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   if (drizzle_state_none(result->con))
   {
     result->options|= DRIZZLE_RESULT_SKIP_COLUMN;
@@ -519,21 +627,25 @@
     drizzle_state_push(result->con, drizzle_state_column_read);
     drizzle_state_push(result->con, drizzle_state_packet_read);
   }
-  ret= drizzle_state_loop(result->con);
+  drizzle_return_t ret= drizzle_state_loop(result->con);
   result->options&= ~DRIZZLE_RESULT_SKIP_COLUMN;
   return ret;
 }
 
 drizzle_return_t drizzle_column_skip_all(drizzle_result_st *result)
 {
-  drizzle_return_t ret;
-  uint16_t it;
+  if (result == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
 
-  for (it= 1; it <= result->column_count; it++)
+  for (uint16_t it= 1; it <= result->column_count; it++)
   {
-    ret= drizzle_column_skip(result);
+    drizzle_return_t ret= drizzle_column_skip(result);
     if (ret != DRIZZLE_RETURN_OK)
+    {
       return ret;
+    }
   }
 
   return DRIZZLE_RETURN_OK;
@@ -543,6 +655,11 @@
                                        drizzle_column_st *column,
                                        drizzle_return_t *ret_ptr)
 {
+  if (result == NULL)
+  {
+    return NULL;
+  }
+
   if (drizzle_state_none(result->con))
   {
     result->column= column;
@@ -557,6 +674,11 @@
 
 drizzle_return_t drizzle_column_buffer(drizzle_result_st *result)
 {
+  if (result == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   drizzle_return_t ret;
 
   if (result->column_buffer == NULL)
@@ -567,7 +689,12 @@
       return DRIZZLE_RETURN_OK;
     }
 
-    result->column_buffer= new drizzle_column_st[result->column_count];
+    result->column_buffer= new (std::nothrow) drizzle_column_st[result->column_count];
+
+    if (result->column_buffer == NULL)
+    {
+      return DRIZZLE_RETURN_MEMORY;
+    }
   }
 
   /* No while body, just keep calling to buffer columns. */
@@ -587,8 +714,15 @@
 
 drizzle_column_st *drizzle_column_next(drizzle_result_st *result)
 {
+  if (result == NULL)
+  {
+    return NULL;
+  }
+
   if (result->column_current == result->column_count)
+  {
     return NULL;
+  }
 
   result->column_current++;
   return &(result->column_buffer[result->column_current - 1]);
@@ -605,21 +739,39 @@
 
 void drizzle_column_seek(drizzle_result_st *result, uint16_t column)
 {
+  if (result == NULL)
+  {
+    return;
+  }
+
   if (column <= result->column_count)
+  {
     result->column_current= column;
+  }
 }
 
-drizzle_column_st *drizzle_column_index(drizzle_result_st *result,
-                                        uint16_t column)
+drizzle_column_st *drizzle_column_index(drizzle_result_st *result, uint16_t column)
 {
+  if (result == NULL)
+  {
+    return NULL;
+  }
+
   if (column >= result->column_count)
+  {
     return NULL;
+  }
 
   return &(result->column_buffer[column]);
 }
 
 uint16_t drizzle_column_current(drizzle_result_st *result)
 {
+  if (result == NULL)
+  {
+    return 0;
+  }
+
   return result->column_current;
 }
 
@@ -630,6 +782,11 @@
 drizzle_return_t drizzle_column_write(drizzle_result_st *result,
                                       drizzle_column_st *column)
 {
+  if (result == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   if (drizzle_state_none(result->con))
   {
     result->column= column;
@@ -642,8 +799,15 @@
 
 void drizzle_column_set_catalog(drizzle_column_st *column, const char *catalog)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (catalog == NULL)
+  {
     column->catalog[0]= 0;
+  }
   else
   {
     strncpy(column->catalog, catalog, DRIZZLE_MAX_CATALOG_SIZE);
@@ -651,21 +815,41 @@
   }
 }
 
-void drizzle_column_set_db(drizzle_column_st *column, const char *db)
+void drizzle_column_set_schema(drizzle_column_st *column, const char *schema)
 {
-  if (db == NULL)
-    column->db[0]= 0;
+  if (column == NULL)
+  {
+    return;
+  }
+
+  if (schema == NULL)
+  {
+    column->schema[0]= 0;
+  }
   else
   {
-    strncpy(column->db, db, DRIZZLE_MAX_DB_SIZE);
-    column->db[DRIZZLE_MAX_DB_SIZE - 1]= 0;
+    strncpy(column->schema, schema, DRIZZLE_MAX_DB_SIZE);
+    column->schema[DRIZZLE_MAX_DB_SIZE - 1]= 0;
   }
 }
 
+void drizzle_column_set_db(drizzle_column_st *column, const char *schema)
+{
+  drizzle_column_set_schema(column, schema);
+}
+
+
 void drizzle_column_set_table(drizzle_column_st *column, const char *table)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (table == NULL)
+  {
     column->table[0]= 0;
+  }
   else
   {
     strncpy(column->table, table, DRIZZLE_MAX_TABLE_SIZE);
@@ -676,6 +860,11 @@
 void drizzle_column_set_orig_table(drizzle_column_st *column,
                                    const char *orig_table)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (orig_table == NULL)
     column->orig_table[0]= 0;
   else
@@ -687,6 +876,11 @@
 
 void drizzle_column_set_name(drizzle_column_st *column, const char *name)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (name == NULL)
     column->name[0]= 0;
   else
@@ -699,6 +893,11 @@
 void drizzle_column_set_orig_name(drizzle_column_st *column,
                                   const char *orig_name)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (orig_name == NULL)
     column->orig_name[0]= 0;
   else
@@ -711,28 +910,53 @@
 void drizzle_column_set_charset(drizzle_column_st *column,
                                 drizzle_charset_t charset)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->charset= charset;
 }
 
 void drizzle_column_set_size(drizzle_column_st *column, uint32_t size)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->size= size;
 }
 
 void drizzle_column_set_type(drizzle_column_st *column,
                              drizzle_column_type_t type)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->type= type;
 }
 
 void drizzle_column_set_flags(drizzle_column_st *column,
                               int flags)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->flags= flags;
 }
 
 void drizzle_column_set_decimals(drizzle_column_st *column, uint8_t decimals)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   column->decimals= decimals;
 }
 
@@ -740,8 +964,15 @@
                                       const uint8_t *default_value,
                                       size_t size)
 {
+  if (column == NULL)
+  {
+    return;
+  }
+
   if (default_value == NULL)
+  {
     column->default_value[0]= 0;
+  }
   else
   {
     if (size < DRIZZLE_MAX_DEFAULT_VALUE_SIZE)
@@ -766,6 +997,11 @@
 
 drizzle_return_t drizzle_state_column_read(drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   drizzle_column_st *column;
   drizzle_column_type_drizzle_t drizzle_type;
 
@@ -809,7 +1045,7 @@
     /* These functions can only fail if they need to read data, but we know we
        buffered the entire packet, so ignore returns. */
     (void)drizzle_unpack_string(con, column->catalog, DRIZZLE_MAX_CATALOG_SIZE);
-    (void)drizzle_unpack_string(con, column->db, DRIZZLE_MAX_DB_SIZE);
+    (void)drizzle_unpack_string(con, column->schema, DRIZZLE_MAX_DB_SIZE);
     (void)drizzle_unpack_string(con, column->table, DRIZZLE_MAX_TABLE_SIZE);
     (void)drizzle_unpack_string(con, column->orig_table,
                                 DRIZZLE_MAX_TABLE_SIZE);
@@ -867,6 +1103,11 @@
 
 drizzle_return_t drizzle_state_column_write(drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   uint8_t *start= con->buffer_ptr + con->buffer_size;
   uint8_t *ptr;
   drizzle_column_st *column= con->result->column;
@@ -875,7 +1116,7 @@
 
   /* Calculate max packet size. */
   con->packet_size= 9 + strlen(column->catalog)
-                  + 9 + strlen(column->db)
+                  + 9 + strlen(column->schema)
                   + 9 + strlen(column->table)
                   + 9 + strlen(column->orig_table)
                   + 9 + strlen(column->name)
@@ -912,7 +1153,7 @@
   ptr+= 4;
 
   ptr= drizzle_pack_string(column->catalog, ptr);
-  ptr= drizzle_pack_string(column->db, ptr);
+  ptr= drizzle_pack_string(column->schema, ptr);
   ptr= drizzle_pack_string(column->table, ptr);
   ptr= drizzle_pack_string(column->orig_table, ptr);
   ptr= drizzle_pack_string(column->name, ptr);

=== modified file 'libdrizzle-2.0/column.h'
--- libdrizzle-2.0/column.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/column.h	2011-11-18 16:11:02 +0000
@@ -82,9 +82,12 @@
 const char *drizzle_column_catalog(drizzle_column_st *column);
 
 /**
- * Get database name for a column.
+ * Get schema name for a column.
  */
 DRIZZLE_API
+const char *drizzle_column_shema(drizzle_column_st *column);
+
+DRIZZLE_API
 const char *drizzle_column_db(drizzle_column_st *column);
 
 /**
@@ -145,8 +148,7 @@
  * Get the Drizzle type of a column.
  */
 DRIZZLE_API
-drizzle_column_type_drizzle_t
-drizzle_column_type_drizzle(drizzle_column_st *column);
+drizzle_column_type_drizzle_t drizzle_column_type_drizzle(drizzle_column_st *column);
 
 /**
  * Get flags for a column.

=== modified file 'libdrizzle-2.0/column_server.h'
--- libdrizzle-2.0/column_server.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/column_server.h	2011-11-18 02:03:41 +0000
@@ -71,6 +71,9 @@
  */
 DRIZZLE_API
 void drizzle_column_set_db(drizzle_column_st *column, const char *db);
+
+DRIZZLE_API
+void drizzle_column_set_schema(drizzle_column_st *column, const char *schema);
  
 /**
  * Set table name for a column.

=== modified file 'libdrizzle-2.0/command.cc'
--- libdrizzle-2.0/command.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/command.cc	2011-11-18 02:03:41 +0000
@@ -120,9 +120,13 @@
   con->buffer_size-= con->command_size;
 
   if (con->command_offset == con->command_total)
+  {
     drizzle_state_pop(con);
+  }
   else
+  {
     return DRIZZLE_RETURN_PAUSE;
+  }
 
   return DRIZZLE_RETURN_OK;
 }
@@ -159,7 +163,7 @@
                     + strlen(con->user) + 1
                     + 1  /* Scramble size */
                     + DRIZZLE_MAX_SCRAMBLE_SIZE
-                    + strlen(con->db) + 1;
+                    + strlen(con->schema) +1;
 
     /* Flush buffer if there is not enough room. */
     free_size= (size_t)DRIZZLE_MAX_BUFFER_SIZE - (size_t)(start - con->buffer);
@@ -174,9 +178,13 @@
     ptr= start;
     ptr[3]= 0;
     if (con->options & DRIZZLE_CON_MYSQL)
-      ptr[4]= (uint8_t)(con->command);
+    {
+      ptr[4]= uint8_t(con->command);
+    }
     else
-      ptr[4]= (uint8_t)(_command_drizzle_map[con->command]);
+    {
+      ptr[4]= uint8_t(_command_drizzle_map[con->command]);
+    }
     ptr+= 5;
 
     if (con->command == DRIZZLE_COMMAND_CHANGE_USER)

=== modified file 'libdrizzle-2.0/conn.cc'
--- libdrizzle-2.0/conn.cc	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/conn.cc	2011-11-18 16:11:02 +0000
@@ -267,7 +267,9 @@
   }
 
   if (password == NULL)
+  {
     con->password[0]= 0;
+  }
   else
   {
     strncpy(con->password, password, DRIZZLE_MAX_PASSWORD_SIZE);
@@ -275,93 +277,173 @@
   }
 }
 
+const char *drizzle_con_schema(const drizzle_con_st *con)
+{
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
+  return con->schema;
+}
+
 const char *drizzle_con_db(const drizzle_con_st *con)
 {
-  return con->db;
+  return drizzle_con_schema(con);
 }
 
-void drizzle_con_set_db(drizzle_con_st *con, const char *db)
+void drizzle_con_set_schema(drizzle_con_st *con, const char *schema)
 {
-  if (db == NULL)
-    con->db[0]= 0;
+  if (con == NULL)
+  {
+    return;
+  }
+
+  if (schema == NULL)
+  {
+    con->schema[0]= 0;
+  }
   else
   {
-    strncpy(con->db, db, DRIZZLE_MAX_DB_SIZE);
-    con->db[DRIZZLE_MAX_DB_SIZE - 1]= 0;
+    strncpy(con->schema, schema, DRIZZLE_MAX_DB_SIZE);
+    con->schema[DRIZZLE_MAX_DB_SIZE - 1]= 0;
   }
 }
 
+void drizzle_con_set_db(drizzle_con_st *con, const char *schema)
+{
+  drizzle_con_set_schema(con, schema);
+}
+
 void *drizzle_con_context(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
   return con->context;
 }
 
 void drizzle_con_set_context(drizzle_con_st *con, void *context)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->context= context;
 }
 
 void drizzle_con_set_context_free_fn(drizzle_con_st *con,
                                      drizzle_con_context_free_fn *function)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->context_free_fn= function;
 }
 
 uint8_t drizzle_con_protocol_version(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->protocol_version;
 }
 
 const char *drizzle_con_server_version(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
   return con->server_version;
 }
 
 uint32_t drizzle_con_server_version_number(const drizzle_con_st *con)
 {
-  uint32_t major;
-  uint32_t minor;
-  uint32_t version;
+  if (con == NULL)
+  {
+    return 0;
+  }
+
+  const char *current= con->server_version;
+
   char *end;
-
-  const char *current= con->server_version;
-
-  major= (uint32_t)strtoul(current, &end, 10);
-  current= end + 1;
-  minor= (uint32_t)strtoul(current, &end, 10);
-  current= end + 1;
-  version= (uint32_t)strtoul(current, &end, 10);
+  uint32_t major= (uint32_t)strtoul(current, &end, 10);
+  current= end + 1;
+
+  uint32_t minor= (uint32_t)strtoul(current, &end, 10);
+  current= end + 1;
+
+  uint32_t version= (uint32_t)strtoul(current, &end, 10);
 
   return (major * 10000) + (minor * 100) + version;
 }
 
 uint32_t drizzle_con_thread_id(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->thread_id;
 }
 
 const uint8_t *drizzle_con_scramble(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->scramble;
 }
 
 int drizzle_con_capabilities(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->capabilities;
 }
 
 drizzle_charset_t drizzle_con_charset(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return drizzle_charset_t();
+  }
+
   return con->charset;
 }
 
 drizzle_con_status_t drizzle_con_status(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return drizzle_con_status_t();
+  }
+
   return con->status;
 }
 
 uint32_t drizzle_con_max_packet_size(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->max_packet_size;
 }
 
@@ -371,8 +453,15 @@
 
 drizzle_return_t drizzle_con_connect(drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   if (con->options & DRIZZLE_CON_READY)
+  {
     return DRIZZLE_RETURN_OK;
+  }
 
   if (drizzle_state_none(con))
   {
@@ -426,6 +515,11 @@
                                         drizzle_result_st *result,
                                         drizzle_return_t *ret_ptr)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
   if (con->options & DRIZZLE_CON_MYSQL)
   {
     return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_SHUTDOWN,
@@ -437,10 +531,9 @@
 }
 
 drizzle_result_st *drizzle_shutdown(drizzle_con_st *con,
-                                    drizzle_result_st *result, uint32_t level,
+                                    drizzle_result_st *result, uint32_t,
                                     drizzle_return_t *ret_ptr)
 {
-  (void) level;
   return drizzle_con_shutdown(con, result, ret_ptr);
 }
 
@@ -476,7 +569,10 @@
                                              size_t total,
                                              drizzle_return_t *ret_ptr)
 {
-  drizzle_result_st *old_result;
+  if (con == NULL)
+  {
+    return NULL;
+  }
 
   drizzle_return_t unused;
   if (ret_ptr == NULL)
@@ -484,20 +580,19 @@
     ret_ptr= &unused;
   }
 
-  if (!(con->options & DRIZZLE_CON_READY))
+  if ((con->options & DRIZZLE_CON_READY) == 0)
   {
     if (con->options & DRIZZLE_CON_RAW_PACKET)
     {
-      drizzle_set_error(con->drizzle, "drizzle_command_write",
-                        "connection not ready");
+      drizzle_set_error(con->drizzle, "drizzle_command_write", "connection not ready");
       *ret_ptr= DRIZZLE_RETURN_NOT_READY;
-      return result;
+      return NULL;
     }
 
     *ret_ptr= drizzle_con_connect(con);
     if (*ret_ptr != DRIZZLE_RETURN_OK)
     {
-      return result;
+      return NULL;
     }
   }
 
@@ -509,13 +604,13 @@
     }
     else
     {
-      for (old_result= con->result_list; old_result != NULL; old_result= old_result->next)
+      for (drizzle_result_st *old_result= con->result_list; old_result != NULL; old_result= old_result->next)
       {
         if (result == old_result)
         {
           drizzle_set_error(con->drizzle, "drizzle_command_write", "result struct already in use");
           *ret_ptr= DRIZZLE_RETURN_INTERNAL_ERROR;
-          return result;
+          return NULL;
         }
       }
 
@@ -543,7 +638,9 @@
 
   *ret_ptr= drizzle_state_loop(con);
   if (*ret_ptr == DRIZZLE_RETURN_PAUSE)
+  {
     *ret_ptr= DRIZZLE_RETURN_OK;
+  }
   else if (*ret_ptr != DRIZZLE_RETURN_OK &&
            *ret_ptr != DRIZZLE_RETURN_IO_WAIT &&
            *ret_ptr != DRIZZLE_RETURN_ERROR_CODE)
@@ -561,8 +658,15 @@
 
 drizzle_return_t drizzle_con_listen(drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   if (con->options & DRIZZLE_CON_READY)
+  {
     return DRIZZLE_RETURN_OK;
+  }
 
   if (drizzle_state_none(con))
   {
@@ -575,25 +679,46 @@
 
 int drizzle_con_backlog(const drizzle_con_st *con)
 {
+  if (con == NULL)
+  {
+    return 0;
+  }
+
   return con->backlog;
 }
 
 void drizzle_con_set_backlog(drizzle_con_st *con, int backlog)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->backlog= backlog;
 }
 
-void drizzle_con_set_protocol_version(drizzle_con_st *con,
-                                      uint8_t protocol_version)
+void drizzle_con_set_protocol_version(drizzle_con_st *con, uint8_t protocol_version)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->protocol_version= protocol_version;
 }
 
 void drizzle_con_set_server_version(drizzle_con_st *con,
                                     const char *server_version)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   if (server_version == NULL)
+  {
     con->server_version[0]= 0;
+  }
   else
   {
     strncpy(con->server_version, server_version,
@@ -604,13 +729,25 @@
 
 void drizzle_con_set_thread_id(drizzle_con_st *con, uint32_t thread_id)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->thread_id= thread_id;
 }
 
 void drizzle_con_set_scramble(drizzle_con_st *con, const uint8_t *scramble)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   if (scramble == NULL)
+  {
     con->scramble= NULL;
+  }
   else
   {
     con->scramble= con->scramble_buffer;
@@ -621,30 +758,55 @@
 void drizzle_con_set_capabilities(drizzle_con_st *con,
                                   int capabilities)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->capabilities= capabilities;
 }
 
 void drizzle_con_set_charset(drizzle_con_st *con, drizzle_charset_t charset)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->charset= charset;
 }
 
 void drizzle_con_set_status(drizzle_con_st *con, drizzle_con_status_t status)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->status= status;
 }
 
 void drizzle_con_set_max_packet_size(drizzle_con_st *con,
                                      uint32_t max_packet_size)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   con->max_packet_size= max_packet_size;
 }
 
 void drizzle_con_copy_handshake(drizzle_con_st *con, drizzle_con_st *from)
 {
+  if (con == NULL)
+  {
+    return;
+  }
+
   drizzle_con_set_auth(con, from->user, NULL);
   drizzle_con_set_scramble(con, from->scramble);
-  drizzle_con_set_db(con, from->db);
+  drizzle_con_set_db(con, from->schema);
   drizzle_con_set_protocol_version(con, from->protocol_version);
   drizzle_con_set_server_version(con, from->server_version);
   drizzle_con_set_thread_id(con, from->thread_id);
@@ -660,6 +822,17 @@
                                size_t *size, size_t *total,
                                drizzle_return_t *ret_ptr)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
   if (drizzle_state_none(con))
   {
     con->packet_number= 0;
@@ -690,11 +863,30 @@
   size_t offset= 0;
   size_t size= 0;
 
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
+  size_t total_unused;
+  if (total == NULL)
+  {
+    total= &total_unused;
+  }
+
   uint8_t *command_data=
     static_cast<uint8_t *>(drizzle_con_command_read(con, command, &offset,
                                                     &size, total, ret_ptr));
   if (*ret_ptr != DRIZZLE_RETURN_OK)
+  {
     return NULL;
+  }
 
   if (command_data == NULL)
   {
@@ -704,7 +896,14 @@
 
   if (con->command_buffer == NULL)
   {
-    con->command_buffer= new uint8_t[(*total) + 1];
+    con->command_buffer= new (std::nothrow) uint8_t[(*total) + 1];
+
+    if (con->command_buffer == NULL)
+    {
+      *total= 0;
+      *ret_ptr= DRIZZLE_RETURN_MEMORY;
+      return NULL;
+    }
   }
 
   memcpy(con->command_buffer + offset, command_data, size);
@@ -714,7 +913,9 @@
     command_data= (uint8_t *)drizzle_con_command_read(con, command, &offset,
                                                       &size, total, ret_ptr);
     if (*ret_ptr != DRIZZLE_RETURN_OK)
+    {
       return NULL;
+    }
 
     memcpy(con->command_buffer + offset, command_data, size);
   }
@@ -770,6 +971,11 @@
   struct addrinfo ai;
   int ret;
 
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   drizzle_log_debug(con->drizzle, "drizzle_state_addrinfo");
 
   switch (con->socket_type)
@@ -784,11 +990,17 @@
     }
 
     if (tcp->port != 0)
+    {
       snprintf(port, NI_MAXSERV, "%u", tcp->port);
+    }
     else if (con->options & DRIZZLE_CON_MYSQL)
+    {
       snprintf(port, NI_MAXSERV, "%u", DRIZZLE_DEFAULT_TCP_PORT_MYSQL);
+    }
     else
+    {
       snprintf(port, NI_MAXSERV, "%u", DRIZZLE_DEFAULT_TCP_PORT);
+    }
     port[NI_MAXSERV-1]= 0;
 
     memset(&ai, 0, sizeof(ai));
@@ -962,12 +1174,16 @@
     if (ret != DRIZZLE_RETURN_OK)
       return ret;
 
-    if (con->drizzle->options & DRIZZLE_NON_BLOCKING)
+    if (con->drizzle->options.is_non_blocking)
+    {
       return DRIZZLE_RETURN_IO_WAIT;
+    }
 
     ret= drizzle_con_wait(con->drizzle);
     if (ret != DRIZZLE_RETURN_OK)
+    {
       return ret;
+    }
   }
 }
 
@@ -986,7 +1202,7 @@
   }
 
   if ((con->revents & POLLIN) == 0 &&
-      (con->drizzle->options & DRIZZLE_NON_BLOCKING))
+      (con->drizzle->options.is_non_blocking))
   {
     /* non-blocking mode: return IO_WAIT instead of attempting to read. This
      * avoids reading immediately after writing a command, which typically
@@ -1059,12 +1275,16 @@
         if (ret != DRIZZLE_RETURN_OK)
           return ret;
 
-        if (con->drizzle->options & DRIZZLE_NON_BLOCKING)
+        if (con->drizzle->options.is_non_blocking)
+        {
           return DRIZZLE_RETURN_IO_WAIT;
+        }
 
         ret= drizzle_con_wait(con->drizzle);
         if (ret != DRIZZLE_RETURN_OK)
+        {
           return ret;
+        }
 
         continue;
       }
@@ -1162,19 +1382,27 @@
       {
         ret= drizzle_con_set_events(con, POLLOUT);
         if (ret != DRIZZLE_RETURN_OK)
+        {
           return ret;
+        }
 
-        if (con->drizzle->options & DRIZZLE_NON_BLOCKING)
+        if (con->drizzle->options.is_non_blocking)
+        {
           return DRIZZLE_RETURN_IO_WAIT;
+        }
 
         ret= drizzle_con_wait(con->drizzle);
         if (ret != DRIZZLE_RETURN_OK)
+        {
           return ret;
+        }
 
         continue;
       }
       else if (errno == EINTR)
+      {
         continue;
+      }
       else if (errno == EPIPE || errno == ECONNRESET)
       {
         drizzle_set_error(con->drizzle, "drizzle_state_write",

=== modified file 'libdrizzle-2.0/conn.h'
--- libdrizzle-2.0/conn.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/conn.h	2011-11-18 02:03:41 +0000
@@ -290,6 +290,9 @@
  * @return Database associated with this connection.
  */
 DRIZZLE_API
+const char *drizzle_con_schema(const drizzle_con_st *con);
+
+DRIZZLE_API
 const char *drizzle_con_db(const drizzle_con_st *con);
 
 /**
@@ -297,10 +300,13 @@
  *
  * @param[in] con Connection structure previously initialized with
  *  drizzle_con_create(), drizzle_con_clone(), or related functions.
- * @param[in] db Database to use with this connection.
+ * @param[in] schema Database to use with this connection.
  */
 DRIZZLE_API
-void drizzle_con_set_db(drizzle_con_st *con, const char *db);
+void drizzle_con_set_schema(drizzle_con_st *con, const char *schema);
+
+DRIZZLE_API
+void drizzle_con_set_db(drizzle_con_st *con, const char *schema);
 
 /**
  * Get application context pointer for a connection.

=== modified file 'libdrizzle-2.0/constants.h'
--- libdrizzle-2.0/constants.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/constants.h	2011-11-18 16:11:02 +0000
@@ -69,7 +69,8 @@
 #define DRIZZLE_MAX_ERROR_SIZE           2048
 #define DRIZZLE_MAX_USER_SIZE            64
 #define DRIZZLE_MAX_PASSWORD_SIZE        32
-#define DRIZZLE_MAX_DB_SIZE              64
+#define DRIZZLE_MAX_SCHEMA_SIZE          64
+#define DRIZZLE_MAX_DB_SIZE              DRIZZLE_MAX_SCHEMA_SIZE
 #define DRIZZLE_MAX_INFO_SIZE            2048
 #define DRIZZLE_MAX_SQLSTATE_SIZE        5
 #define DRIZZLE_MAX_CATALOG_SIZE         128
@@ -196,8 +197,8 @@
  */
 enum drizzle_con_socket_t
 {
-  DRIZZLE_CON_SOCKET_TCP= 0,
-  DRIZZLE_CON_SOCKET_UDS= (1 << 0)
+  DRIZZLE_CON_SOCKET_TCP,
+  DRIZZLE_CON_SOCKET_UDS
 };
 
 #ifndef __cplusplus
@@ -525,6 +526,7 @@
 class drizzle_result_st;
 class drizzle_column_st;
 #endif
+
 typedef char drizzle_field_t_type;
 typedef drizzle_field_t_type *drizzle_field_t;
 typedef drizzle_field_t drizzle_row_t_type;
@@ -541,15 +543,11 @@
 #endif
 
 /* Function types. */
-typedef void (drizzle_context_free_fn)(drizzle_st *drizzle,
-                                       void *context);
-typedef void (drizzle_log_fn)(const char *line, drizzle_verbose_t verbose,
-                              void *context);
+typedef void (drizzle_context_free_fn)(drizzle_st *drizzle, void *context);
+typedef void (drizzle_log_fn)(const char *line, drizzle_verbose_t verbose, void *context);
 typedef drizzle_return_t (drizzle_state_fn)(drizzle_con_st *con);
-typedef void (drizzle_con_context_free_fn)(drizzle_con_st *con,
-                                           void *context);
-typedef void (drizzle_query_context_free_fn)(drizzle_query_st *query,
-                                             void *context);
+typedef void (drizzle_con_context_free_fn)(drizzle_con_st *con, void *context);
+typedef void (drizzle_query_context_free_fn)(drizzle_query_st *query, void *context);
 /**
  * Custom function to register or deregister interest in file descriptor
  * events. See drizzle_set_event_watch_fn().

=== modified file 'libdrizzle-2.0/drizzle.cc'
--- libdrizzle-2.0/drizzle.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/drizzle.cc	2011-11-18 16:11:02 +0000
@@ -79,7 +79,9 @@
 const char *drizzle_verbose_name(drizzle_verbose_t verbose)
 {
   if (verbose >= DRIZZLE_VERBOSE_MAX)
+  {
     return "UNKNOWN";
+  }
 
   return _verbose_name[verbose];
 }
@@ -101,15 +103,19 @@
 
   if (drizzle == NULL)
   {
-    drizzle= new drizzle_st;
-    drizzle->options= DRIZZLE_ALLOCATED;
+    drizzle= new (std::nothrow) drizzle_st;
+
+    if (drizzle == NULL)
+    {
+      return NULL;
+    }
+    drizzle->options.is_allocated= true;
   }
-  else
-    drizzle->options= DRIZZLE_NONE;
 
   /* @todo remove this default free flag with new API. */
-  drizzle->options|= DRIZZLE_FREE_OBJECTS;
+  drizzle->options.is_free_objects= true;
   drizzle->error_code= 0;
+
   /* drizzle->options set above */
   drizzle->verbose= DRIZZLE_VERBOSE_NEVER;
   drizzle->con_count= 0;
@@ -138,9 +144,13 @@
 {
   drizzle= drizzle_create(drizzle);
   if (drizzle == NULL)
+  {
     return NULL;
+  }
 
-  drizzle->options|= (from->options & ~DRIZZLE_ALLOCATED);
+  bool cache_state= drizzle->options.is_allocated;
+  drizzle->options= from->options;
+  drizzle->options.is_allocated= cache_state;
 
   for (drizzle_con_st* con= from->con_list; con != NULL; con= con->next)
   {
@@ -157,14 +167,16 @@
 void drizzle_free(drizzle_st *drizzle)
 {
   if (drizzle->context != NULL && drizzle->context_free_fn != NULL)
+  {
     drizzle->context_free_fn(drizzle, drizzle->context);
+  }
 
-  if (drizzle->options & DRIZZLE_FREE_OBJECTS)
+  if (drizzle->options.is_free_objects)
   {
     drizzle_con_free_all(drizzle);
     drizzle_query_free_all(drizzle);
   }
-  else if (drizzle->options & DRIZZLE_ASSERT_DANGLING)
+  else if (drizzle->options.is_assert_dangling)
   {
     assert(drizzle->con_list == NULL);
     assert(drizzle->query_list == NULL);
@@ -172,8 +184,10 @@
 
   free(drizzle->pfds);
 
-  if (drizzle->options & DRIZZLE_ALLOCATED)
+  if (drizzle->options.is_allocated)
+  {
     delete drizzle;
+  }
 #if defined(_WIN32)
   /* if it is MS windows, invoke WSACleanup() at the end*/
   WSACleanup();
@@ -200,24 +214,17 @@
   return drizzle->sqlstate;
 }
 
-int drizzle_options(const drizzle_st *drizzle)
-{
-  return drizzle->options;
-}
-
-void drizzle_set_options(drizzle_st *drizzle, int options)
-{
-  drizzle->options= options;
-}
-
-void drizzle_add_options(drizzle_st *drizzle, int options)
-{
-  drizzle->options|= options;
-}
-
-void drizzle_remove_options(drizzle_st *drizzle, drizzle_options_t options)
-{
-  drizzle->options&= ~options;
+int drizzle_options(const drizzle_st *)
+{
+  return 0;
+}
+
+void drizzle_set_options(drizzle_st *, int)
+{
+}
+
+void drizzle_add_options(drizzle_st *, int)
+{
 }
 
 void *drizzle_context(const drizzle_st *drizzle)
@@ -275,14 +282,17 @@
 {
   if (con == NULL)
   {
-    con= new drizzle_con_st;
+    con= new (std::nothrow) drizzle_con_st;
     con->options= DRIZZLE_CON_ALLOCATED;
   }
   else
+  {
     con->options= 0;
+  }
 
   if (drizzle->con_list != NULL)
     drizzle->con_list->prev= con;
+
   con->next= drizzle->con_list;
   con->prev= NULL;
   drizzle->con_list= con;
@@ -326,7 +336,7 @@
   con->socket.tcp.host= NULL;
   con->socket.tcp.port= 0;
   /* con->buffer doesn't need to be set */
-  con->db[0]= 0;
+  con->schema[0]= 0;
   con->password[0]= 0;
   /* con->scramble_buffer doesn't need to be set */
   con->server_version[0]= 0;
@@ -341,14 +351,16 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   /* Clear "operational" options such as IO status. */
   con->options|= (from->options & ~(DRIZZLE_CON_ALLOCATED|DRIZZLE_CON_READY|
                   DRIZZLE_CON_NO_RESULT_READ|DRIZZLE_CON_IO_READY|
                   DRIZZLE_CON_LISTEN));
   con->backlog= from->backlog;
-  strcpy(con->db, from->db);
+  strcpy(con->schema, from->schema);
   strcpy(con->password, from->password);
   strcpy(con->user, from->user);
 
@@ -369,34 +381,52 @@
 void drizzle_con_free(drizzle_con_st *con)
 {
   if (con->context != NULL && con->context_free_fn != NULL)
+  {
     con->context_free_fn(con, con->context);
+  }
 
-  if (con->drizzle->options & DRIZZLE_FREE_OBJECTS)
+  if (con->drizzle->options.is_free_objects)
+  {
     drizzle_result_free_all(con);
-  else if (con->drizzle->options & DRIZZLE_ASSERT_DANGLING)
+  }
+  else if (con->drizzle->options.is_assert_dangling)
+  {
     assert(con->result_list == NULL);
+  }
 
   if (con->fd != -1)
+  {
     drizzle_con_close(con);
+  }
 
   drizzle_con_reset_addrinfo(con);
 
   if (con->drizzle->con_list == con)
+  {
     con->drizzle->con_list= con->next;
+  }
   if (con->prev != NULL)
+  {
     con->prev->next= con->next;
+  }
   if (con->next != NULL)
+  {
     con->next->prev= con->prev;
+  }
   con->drizzle->con_count--;
 
   if (con->options & DRIZZLE_CON_ALLOCATED)
+  {
     delete con;
+  }
 }
 
 void drizzle_con_free_all(drizzle_st *drizzle)
 {
   while (drizzle->con_list != NULL)
+  {
     drizzle_con_free(drizzle->con_list);
+  }
 }
 
 drizzle_return_t drizzle_con_wait(drizzle_st *drizzle)
@@ -418,7 +448,9 @@
     drizzle->pfds_size= drizzle->con_count;
   }
   else
+  {
     pfds= drizzle->pfds;
+  }
 
   uint32_t x= 0;
   for (drizzle_con_st* con= drizzle->con_list; con != NULL; con= con->next)
@@ -528,7 +560,9 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   drizzle_con_set_tcp(con, host, port);
   drizzle_con_set_auth(con, user, password);
@@ -545,7 +579,9 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   drizzle_con_set_uds(con, uds);
   drizzle_con_set_auth(con, user, password);
@@ -567,7 +603,9 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   drizzle_con_set_tcp(con, host, port);
   drizzle_con_set_backlog(con, backlog);
@@ -583,7 +621,9 @@
 {
   con= drizzle_con_create(drizzle, con);
   if (con == NULL)
+  {
     return NULL;
+  }
 
   drizzle_con_set_uds(con, uds);
   drizzle_con_set_backlog(con, backlog);
@@ -623,7 +663,7 @@
       return con;
     }
 
-    if (drizzle->options & DRIZZLE_NON_BLOCKING)
+    if (drizzle->options.is_non_blocking)
     {
       *ret_ptr= DRIZZLE_RETURN_IO_WAIT;
       return NULL;
@@ -662,16 +702,29 @@
   int written= vsnprintf(ptr, DRIZZLE_MAX_ERROR_SIZE - size, format, args);
   va_end(args);
 
-  if (written < 0) size= DRIZZLE_MAX_ERROR_SIZE;
-  else size+= written;
+  if (written < 0) 
+  {
+    size= DRIZZLE_MAX_ERROR_SIZE;
+  }
+  else 
+  {
+    size+= written;
+  }
+
   if (size >= DRIZZLE_MAX_ERROR_SIZE)
+  {
     size= DRIZZLE_MAX_ERROR_SIZE - 1;
+  }
   log_buffer[size]= 0;
 
   if (drizzle->log_fn == NULL)
+  {
     memcpy(drizzle->last_error, log_buffer, size + 1);
+  }
   else
+  {
     drizzle->log_fn(log_buffer, DRIZZLE_VERBOSE_ERROR, drizzle->log_context);
+  }
 }
 
 void drizzle_log(drizzle_st *drizzle, drizzle_verbose_t verbose,

=== modified file 'libdrizzle-2.0/drizzle.h'
--- libdrizzle-2.0/drizzle.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/drizzle.h	2011-11-18 16:11:02 +0000
@@ -251,7 +251,7 @@
  * @param[in] options Available options for drizzle structure to remove.
  */
 DRIZZLE_API
-void drizzle_remove_options(drizzle_st *drizzle, drizzle_options_t options);
+void drizzle_remove_options(drizzle_st *, drizzle_options_t);
 
 /**
  * Get application context pointer.

=== modified file 'libdrizzle-2.0/field.cc'
--- libdrizzle-2.0/field.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/field.cc	2011-11-18 16:11:02 +0000
@@ -77,13 +77,20 @@
 drizzle_field_t drizzle_field_buffer(drizzle_result_st *result, size_t *total,
                                      drizzle_return_t *ret_ptr)
 {
-  drizzle_field_t field;
   size_t offset= 0;
   size_t size= 0;
 
-  field= drizzle_field_read(result, &offset, &size, total, ret_ptr);
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
+  drizzle_field_t field= drizzle_field_read(result, &offset, &size, total, ret_ptr);
   if (*ret_ptr != DRIZZLE_RETURN_OK)
+  {
     return NULL;
+  }
 
   if (field == NULL)
   {
@@ -93,7 +100,14 @@
 
   if (result->field_buffer == NULL)
   {
-    result->field_buffer= new drizzle_field_t_type[(*total) + 1];
+    result->field_buffer= new (std::nothrow) drizzle_field_t_type[(*total) + 1];
+
+    if (result->field_buffer == NULL)
+    {
+      *ret_ptr= DRIZZLE_RETURN_MEMORY;
+      *total= 0;
+      return NULL;
+    }
   }
 
   memcpy(result->field_buffer + offset, field, size);
@@ -102,7 +116,9 @@
   {
     field= drizzle_field_read(result, &offset, &size, total, ret_ptr);
     if (*ret_ptr != DRIZZLE_RETURN_OK)
+    {
       return NULL;
+    }
 
     memcpy(result->field_buffer + offset, field, size);
   }

=== modified file 'libdrizzle-2.0/handshake.cc'
--- libdrizzle-2.0/handshake.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/handshake.cc	2011-11-18 02:03:41 +0000
@@ -401,7 +401,9 @@
   con->buffer_ptr+= 1;
 
   if (scramble_size == 0)
+  {
     con->scramble= NULL;
+  }
   else
   {
     if (scramble_size != DRIZZLE_MAX_SCRAMBLE_SIZE)
@@ -418,9 +420,11 @@
     con->buffer_ptr+= DRIZZLE_MAX_SCRAMBLE_SIZE;
   }
 
-  /* Look for null-terminated db string. */
-  if ((34 + strlen(con->user) + scramble_size) == con->packet_size)
-    con->db[0]= 0;
+  /* Look for null-terminated schema string. */
+  if ((34 + strlen(con->user) +scramble_size) == con->packet_size)
+  {
+    con->schema[0]= 0;
+  }
   else
   {
     ptr= (uint8_t *)memchr(con->buffer_ptr, 0, con->buffer_size -
@@ -428,7 +432,7 @@
     if (ptr == NULL)
     {
       drizzle_set_error(con->drizzle, "drizzle_state_handshake_client_read",
-                        "db string not found");
+                        "schema string not found");
       return DRIZZLE_RETURN_BAD_HANDSHAKE_PACKET;
     }
 
@@ -442,13 +446,13 @@
 
     if (con->buffer_ptr == ptr)
     {
-      con->db[0]= 0;
+      con->schema[0]= 0;
       con->buffer_ptr++;
     }
     else
     {
-      strncpy(con->db, (char *)con->buffer_ptr, DRIZZLE_MAX_DB_SIZE);
-      con->db[DRIZZLE_MAX_DB_SIZE - 1]= 0;
+      strncpy(con->schema, (char *)con->buffer_ptr, DRIZZLE_MAX_DB_SIZE);
+      con->schema[DRIZZLE_MAX_DB_SIZE - 1]= 0;
       con->buffer_ptr+= ((ptr - con->buffer_ptr) + 1);
     }
   }
@@ -471,7 +475,6 @@
 {
   uint8_t *ptr;
   int capabilities;
-  drizzle_return_t ret;
 
   drizzle_log_debug(con->drizzle, "drizzle_state_handshake_client_write");
 
@@ -483,7 +486,7 @@
                   + strlen(con->user) + 1
                   + 1   /* Scramble size */
                   + DRIZZLE_MAX_SCRAMBLE_SIZE
-                  + strlen(con->db) + 1;
+                  + strlen(con->schema) + 1;
 
   /* Assume the entire handshake packet will fit in the buffer. */
   if ((con->packet_size + 4) > DRIZZLE_MAX_BUFFER_SIZE)
@@ -501,7 +504,9 @@
   ptr+= 4;
 
   if (con->options & DRIZZLE_CON_MYSQL)
+  {
     con->capabilities|= DRIZZLE_CAPABILITIES_PROTOCOL_41;
+  }
 
   capabilities= con->capabilities & DRIZZLE_CAPABILITIES_CLIENT;
   if (!(con->options & DRIZZLE_CON_FOUND_ROWS))
@@ -523,8 +528,10 @@
   }
 
   capabilities&= ~(DRIZZLE_CAPABILITIES_COMPRESS | DRIZZLE_CAPABILITIES_SSL);
-  if (con->db[0] == 0)
+  if (con->schema[0] == 0)
+  {
     capabilities&= ~DRIZZLE_CAPABILITIES_CONNECT_WITH_DB;
+  }
 
   drizzle_set_byte4(ptr, capabilities);
   ptr+= 4;
@@ -538,9 +545,12 @@
   memset(ptr, 0, 23);
   ptr+= 23;
 
+  drizzle_return_t ret;
   ptr= drizzle_pack_auth(con, ptr, &ret);
   if (ret != DRIZZLE_RETURN_OK)
+  {
     return ret;
+  }
 
   con->buffer_size+= (4 + con->packet_size);
 
@@ -562,17 +572,18 @@
 
 drizzle_return_t drizzle_state_handshake_result_read(drizzle_con_st *con)
 {
-  drizzle_return_t ret;
   drizzle_result_st result;
 
   drizzle_log_debug(con->drizzle, "drizzle_state_handshake_result_read");
 
   if (drizzle_result_create(con, &result) == NULL)
+  {
     return DRIZZLE_RETURN_MEMORY;
+  }
 
   con->result= &result;
 
-  ret= drizzle_state_result_read(con);
+  drizzle_return_t ret= drizzle_state_result_read(con);
   if (drizzle_state_none(con))
   {
     if (ret == DRIZZLE_RETURN_OK)
@@ -591,7 +602,9 @@
   drizzle_result_free(&result);
 
   if (ret == DRIZZLE_RETURN_ERROR_CODE)
+  {
     return DRIZZLE_RETURN_HANDSHAKE_FAILED;
+  }
 
   return ret;
 }

=== modified file 'libdrizzle-2.0/libdrizzle.hpp'
--- libdrizzle-2.0/libdrizzle.hpp	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/libdrizzle.hpp	2011-11-18 02:03:41 +0000
@@ -247,7 +247,7 @@
   query_c& p_name(const std::string& v)
   {
     std::vector<char> r(2 * v.size() + 2);
-    r.resize(drizzle_escape_string(&r.front() + 1, v.data(), v.size()) + 2);    
+    r.resize(drizzle_escape_string(&r.front() + 1, r.size(), v.data(), v.size()) + 2);    
     r.front() = '`';
     r.back() = '`';
     p_raw(&r.front(), r.size());
@@ -274,7 +274,7 @@
   query_c& p(const std::string& v)
   {
     std::vector<char> r(2 * v.size() + 2);
-    r.resize(drizzle_escape_string(&r.front() + 1, v.data(), v.size()) + 2);    
+    r.resize(drizzle_escape_string(&r.front() + 1, r.size(), v.data(), v.size()) + 2);    
     r.front() = '\'';
     r.back() = '\'';
     p_raw(&r.front(), r.size());

=== modified file 'libdrizzle-2.0/pack.cc'
--- libdrizzle-2.0/pack.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/pack.cc	2011-11-18 02:03:41 +0000
@@ -145,6 +145,11 @@
 
 uint8_t *drizzle_pack_string(char *string, uint8_t *ptr)
 {
+  if (string == NULL)
+  {
+    return NULL;
+  }
+
   uint64_t size= strlen(string);
 
   ptr= drizzle_pack_length(size, ptr);
@@ -163,6 +168,11 @@
   drizzle_return_t ret= DRIZZLE_RETURN_OK;
   uint64_t length;
 
+  if (con == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
+
   length= drizzle_unpack_length(con, &ret);
   if (ret != DRIZZLE_RETURN_OK)
   {
@@ -178,7 +188,9 @@
   if (length < max_length)
   {
     if (length > 0)
+    {
       memcpy(buffer, con->buffer_ptr, (size_t)length);
+    }
 
     buffer[length]= 0;
   }
@@ -195,9 +207,19 @@
   return DRIZZLE_RETURN_OK;
 }
 
-uint8_t *drizzle_pack_auth(drizzle_con_st *con, uint8_t *ptr,
-                           drizzle_return_t *ret_ptr)
+uint8_t *drizzle_pack_auth(drizzle_con_st *con, uint8_t *ptr, drizzle_return_t *ret_ptr)
 {
+  if (con == NULL)
+  {
+    return NULL;
+  }
+
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
   if (con->user[0] != 0)
   {
     memcpy(ptr, con->user, strlen(con->user));
@@ -235,7 +257,9 @@
     {
       *ret_ptr= _pack_scramble_hash(con, ptr);
       if (*ret_ptr != DRIZZLE_RETURN_OK)
+      {
         return ptr;
+      }
     }
     else // We assume Drizzle
     {
@@ -246,16 +270,17 @@
     ptr+= DRIZZLE_MAX_SCRAMBLE_SIZE;
   }
 
-  if (con->db[0] != 0)
+  if (con->schema[0] != 0)
   {
-    memcpy(ptr, con->db, strlen(con->db));
-    ptr+= strlen(con->db);
+    memcpy(ptr, con->schema, strlen(con->schema));
+    ptr+= strlen(con->schema);
   }
 
   ptr[0]= 0;
   ptr++;
 
   *ret_ptr= DRIZZLE_RETURN_OK;
+
   return ptr;
 }
 
@@ -266,7 +291,6 @@
 static drizzle_return_t _pack_scramble_hash(drizzle_con_st *con,
                                             uint8_t *buffer)
 {
-  uint32_t x;
   SHA1_CTX ctx;
   uint8_t hash_tmp1[SHA1_DIGEST_LENGTH];
   uint8_t hash_tmp2[SHA1_DIGEST_LENGTH];
@@ -303,8 +327,10 @@
   SHA1Final(buffer, &ctx);
 
   /* Fourth, xor the last hash against the first password hash. */
-  for (x= 0; x < SHA1_DIGEST_LENGTH; x++)
+  for (uint32_t x= 0; x < SHA1_DIGEST_LENGTH; x++)
+  {
     buffer[x]= buffer[x] ^ hash_tmp1[x];
+  }
 
   return DRIZZLE_RETURN_OK;
 }

=== modified file 'libdrizzle-2.0/query.cc'
--- libdrizzle-2.0/query.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/query.cc	2011-11-18 16:11:02 +0000
@@ -54,12 +54,9 @@
                                      const char *query, 
                                      drizzle_return_t *ret_ptr)
 {
-  size_t size;
-
-  size= strlen(query);
-
-  return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_QUERY,
-                                   (uint8_t *)query, size, size, ret_ptr);
+  size_t size= strlen(query);
+
+  return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_QUERY, (uint8_t *)query, size, size, ret_ptr);
 }
 
 drizzle_result_st *drizzle_query_inc(drizzle_con_st *con,
@@ -67,8 +64,7 @@
                                      const char *query, size_t size,
                                      size_t total, drizzle_return_t *ret_ptr)
 {
-  return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_QUERY,
-                                   (uint8_t *)query, size, total, ret_ptr);
+  return drizzle_con_command_write(con, result, DRIZZLE_COMMAND_QUERY, (uint8_t *)query, size, total, ret_ptr);
 }
 
 drizzle_query_st *drizzle_query_add(drizzle_st *drizzle,
@@ -79,9 +75,12 @@
                                     drizzle_query_options_t options,
                                     void *context)
 {
+  // @note drizzle_query_st handle the null drizzle case
   query= drizzle_query_create(drizzle, query);
   if (query == NULL)
+  {
     return NULL;
+  }
 
   drizzle_query_set_con(query, con);
   drizzle_query_set_result(query, result);
@@ -95,9 +94,19 @@
 drizzle_query_st *drizzle_query_create(drizzle_st *drizzle,
                                        drizzle_query_st *query)
 {
+  if (drizzle == NULL)
+  {
+    return NULL;
+  }
+
   if (query == NULL)
   {
-    query= new drizzle_query_st;
+    query= new (std::nothrow) drizzle_query_st;
+
+    if (query == NULL)
+    {
+      return NULL;
+    }
     query->options|= DRIZZLE_CON_ALLOCATED;
   }
   else
@@ -116,7 +125,9 @@
   query->drizzle= drizzle;
 
   if (drizzle->query_list)
+  {
     drizzle->query_list->prev= query;
+  }
   query->next= drizzle->query_list;
   drizzle->query_list= query;
   drizzle->query_count++;
@@ -127,15 +138,23 @@
 
 void drizzle_query_free(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   if (query->context != NULL && query->context_free_fn != NULL)
     query->context_free_fn(query, query->context);
 
   if (query->drizzle->query_list == query)
     query->drizzle->query_list= query->next;
+
   if (query->prev)
     query->prev->next= query->next;
+
   if (query->next)
     query->next->prev= query->prev;
+
   query->drizzle->query_count--;
 
   if (query->options & DRIZZLE_QUERY_ALLOCATED)
@@ -145,32 +164,59 @@
 void drizzle_query_free_all(drizzle_st *drizzle)
 {
   while (drizzle->query_list != NULL)
+  {
     drizzle_query_free(drizzle->query_list);
+  }
 }
 
 drizzle_con_st *drizzle_query_con(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return NULL;
+  }
+
   return query->con;
 }
 
 void drizzle_query_set_con(drizzle_query_st *query, drizzle_con_st *con)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->con= con;
 }
 
 drizzle_result_st *drizzle_query_result(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return NULL;
+  }
+
   return query->result;
 }
 
 void drizzle_query_set_result(drizzle_query_st *query,
                               drizzle_result_st *result)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->result= result;
 }
 
 char *drizzle_query_string(drizzle_query_st *query, size_t *size)
 {
+  if (query == NULL)
+  {
+    return NULL;
+  }
+
   *size= query->size;
   return (char *)(query->string);
 }
@@ -178,56 +224,102 @@
 void drizzle_query_set_string(drizzle_query_st *query, const char *string,
                               size_t size)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->string= string;
   query->size= size;
 }
 
 int drizzle_query_options(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return 0;
+  }
+
   return query->options;
 }
 
 void drizzle_query_set_options(drizzle_query_st *query,
                                int options)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->options= options;
 }
 
 void drizzle_query_add_options(drizzle_query_st *query,
                                int options)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->options|= options;
 }
 
 void drizzle_query_remove_options(drizzle_query_st *query,
                                   int options)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->options&= ~options;
 }
 
 void *drizzle_query_context(drizzle_query_st *query)
 {
+  if (query == NULL)
+  {
+    return NULL;
+  }
+
   return query->context;
 }
 
 void drizzle_query_set_context(drizzle_query_st *query, void *context)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->context= context;
 }
 
 void drizzle_query_set_context_free_fn(drizzle_query_st *query,
                                        drizzle_query_context_free_fn *function)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   query->context_free_fn= function;
 }
 
 static void drizzle_query_run_state(drizzle_query_st* query,
                                     drizzle_return_t* ret_ptr)
 {
+  if (query == NULL)
+  {
+    return;
+  }
+
   switch (query->state)
   {
   case DRIZZLE_QUERY_STATE_INIT:
     query->state= DRIZZLE_QUERY_STATE_QUERY;
+
   case DRIZZLE_QUERY_STATE_QUERY:
     query->result= drizzle_query(query->con, query->result, query->string,
                                  query->size, ret_ptr);
@@ -262,9 +354,17 @@
 drizzle_query_st *drizzle_query_run(drizzle_st *drizzle,
                                     drizzle_return_t *ret_ptr)
 {
-  int options;
-  drizzle_query_st *query;
-  drizzle_con_st *con;
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
+  if (drizzle == NULL)
+  {
+    *ret_ptr= DRIZZLE_RETURN_INVALID_ARGUMENT;
+    return NULL;
+  }
 
   if (drizzle->query_new == 0 && drizzle->query_running == 0)
   {
@@ -272,16 +372,18 @@
     return NULL;
   }
 
-  options= drizzle->options;
-  drizzle->options|= DRIZZLE_NON_BLOCKING;
+  drizzle_st::options_t options= drizzle->options;
+  drizzle->options.is_non_blocking= false;
 
   /* Check to see if any queries need to be started. */
   if (drizzle->query_new > 0)
   {
-    for (query= drizzle->query_list; query != NULL; query= query->next)
+    for (drizzle_query_st *query= drizzle->query_list; query != NULL; query= query->next)
     {
       if (query->state != DRIZZLE_QUERY_STATE_INIT)
+      {
         continue;
+      }
 
       drizzle->query_new--;
       drizzle->query_running++;
@@ -307,10 +409,12 @@
 
   while (1)
   {
+    drizzle_con_st *con;
+
     /* Loop through each active connection. */
     while ((con= drizzle_con_ready(drizzle)) != NULL)
     {
-      query= con->query;
+      drizzle_query_st *query= con->query;
       drizzle_query_run_state(query, ret_ptr);
       if (query->state == DRIZZLE_QUERY_STATE_DONE)
       {
@@ -322,7 +426,7 @@
       assert(*ret_ptr == DRIZZLE_RETURN_IO_WAIT);
     }
 
-    if (options & DRIZZLE_NON_BLOCKING)
+    if (options.is_non_blocking)
     {
       *ret_ptr= DRIZZLE_RETURN_IO_WAIT;
       return NULL;
@@ -339,19 +443,26 @@
 
 drizzle_return_t drizzle_query_run_all(drizzle_st *drizzle)
 {
-  drizzle_return_t ret;
+  if (drizzle == NULL)
+  {
+    return DRIZZLE_RETURN_INVALID_ARGUMENT;
+  }
 
   while (drizzle->query_new > 0 || drizzle->query_running > 0)
   {
+    drizzle_return_t ret;
+
     (void)drizzle_query_run(drizzle, &ret);
     if (ret != DRIZZLE_RETURN_OK && ret != DRIZZLE_RETURN_ERROR_CODE)
+    {
       return ret;
+    }
   }
 
   return DRIZZLE_RETURN_OK;
 }
 
-ssize_t drizzle_safe_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size)
+ssize_t drizzle_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size)
 {
   ssize_t to_size= 0;
   char newchar;
@@ -393,7 +504,9 @@
     if (newchar != '\0')
     {
       if ((size_t)to_size + 2 > max_to_size)
+      {
         return -1;
+      }
 
       *to++= '\\';
       *to++= newchar;
@@ -402,7 +515,9 @@
     else
     {
       if ((size_t)to_size + 1 > max_to_size)
+      {
         return -1;
+      }
 
       *to++= *from;
     }
@@ -414,11 +529,6 @@
   return to_size;
 }
 
-size_t drizzle_escape_string(char *to, const char *from, size_t from_size)
-{
-  return (size_t) drizzle_safe_escape_string(to, (from_size * 2), from, from_size);
-}
-
 size_t drizzle_hex_string(char *to, const char *from, size_t from_size)
 {
   static const char hex_map[]= "0123456789ABCDEF";

=== modified file 'libdrizzle-2.0/query.h'
--- libdrizzle-2.0/query.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/query.h	2011-11-18 02:03:41 +0000
@@ -227,11 +227,11 @@
  * size of the output string in to.
  */
 DRIZZLE_API
-size_t drizzle_escape_string(char *to, const char *from, size_t from_size);
-DRIZZLE_API
-ssize_t drizzle_safe_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size);
+ssize_t drizzle_escape_string(char *to, size_t max_to_size, const char *from, size_t from_size);
+
 DRIZZLE_API
 size_t drizzle_hex_string(char *to, const char *from, size_t from_size);
+
 DRIZZLE_API
 void drizzle_mysql_password_hash(char *to, const char *from, size_t from_size);
 

=== modified file 'libdrizzle-2.0/result.cc'
--- libdrizzle-2.0/result.cc	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/result.cc	2011-11-18 16:11:02 +0000
@@ -51,7 +51,13 @@
 {
   if (result == NULL)
   {
-    result= new drizzle_result_st;
+    result= new (std::nothrow) drizzle_result_st;
+
+    if (result == NULL)
+    {
+      return NULL;
+    }
+
     result->options|= DRIZZLE_RESULT_ALLOCATED;
   }
   else
@@ -328,14 +334,13 @@
     return DRIZZLE_RETURN_INVALID_ARGUMENT;
   }
 
-  drizzle_return_t ret;
-  drizzle_row_t row;
-
   if (!(result->options & DRIZZLE_RESULT_BUFFER_COLUMN))
   {
-    ret= drizzle_column_buffer(result);
+    drizzle_return_t ret= drizzle_column_buffer(result);
     if (ret != DRIZZLE_RETURN_OK)
+    {
       return ret;
+    }
   }
 
   if (result->column_count == 0)
@@ -346,22 +351,36 @@
 
   while (1)
   {
-    row= drizzle_row_buffer(result, &ret);
+    drizzle_return_t ret;
+    drizzle_row_t row= drizzle_row_buffer(result, &ret);
     if (ret != DRIZZLE_RETURN_OK)
+    {
       return ret;
+    }
 
     if (row == NULL)
+    {
       break;
+    }
 
     if (result->row_list == NULL)
     {
-      result->row_list= new drizzle_row_list_t;
+      result->row_list= new (std::nothrow) drizzle_row_list_t;
+
+      if (result->row_list == NULL)
+      {
+        return DRIZZLE_RETURN_MEMORY;
+      }
     }
 
 
     if (result->field_sizes_list == NULL)
     {
-      result->field_sizes_list= new drizzle_field_sizes_list_t;
+      result->field_sizes_list= new (std::nothrow) drizzle_field_sizes_list_t;
+
+      if (result->field_sizes_list == NULL)
+      {
+      }
     }
 
     result->row_list->push_back(row);
@@ -369,6 +388,7 @@
   }
 
   result->options|= DRIZZLE_RESULT_BUFFER_ROW;
+
   return DRIZZLE_RETURN_OK;
 }
 
@@ -426,22 +446,30 @@
     return;
   }
 
-  uint16_t x;
-
   result->con->packet_size= 0;
 
-  for (x= 0; x < result->column_count; x++)
+  for (uint16_t x= 0; x < result->column_count; x++)
   {
     if (field[x] == NULL)
+    {
       result->con->packet_size++;
+    }
     else if (size[x] < 251)
+    {
       result->con->packet_size+= (1 + size[x]);
+    }
     else if (size[x] < 65536)
+    {
       result->con->packet_size+= (3 + size[x]);
+    }
     else if (size[x] < 16777216)
+    {
       result->con->packet_size+= (4 + size[x]);
+    }
     else
+    {
       result->con->packet_size+= (9 + size[x]);
+    }
   }
 }
 
@@ -453,9 +481,13 @@
   }
 
   if (is_eof)
+  {
     result->options|= DRIZZLE_RESULT_EOF_PACKET;
+  }
   else
+  {
     result->options&= ~DRIZZLE_RESULT_EOF_PACKET;
+  }
 }
 
 void drizzle_result_set_info(drizzle_result_st *result, const char *info)
@@ -580,6 +612,7 @@
   if (con->buffer_size < con->packet_size)
   {
     drizzle_state_push(con, drizzle_state_read);
+
     return DRIZZLE_RETURN_OK;
   }
 
@@ -649,6 +682,7 @@
   }
 
   drizzle_state_pop(con);
+
   return ret;
 }
 
@@ -676,8 +710,8 @@
   /* Assume the entire result packet will fit in the buffer. */
   if ((con->packet_size + 4) > DRIZZLE_MAX_BUFFER_SIZE)
   {
-    drizzle_set_error(con->drizzle, "drizzle_state_result_write",
-                      "buffer too small:%zu", con->packet_size + 4);
+    drizzle_set_error(con->drizzle, "drizzle_state_result_write", "buffer too small:%zu", con->packet_size + 4);
+
     return DRIZZLE_RETURN_INTERNAL_ERROR;
   }
 
@@ -686,6 +720,7 @@
       con->packet_size)
   {
     drizzle_state_push(con, drizzle_state_write);
+
     return DRIZZLE_RETURN_OK;
   }
 
@@ -750,5 +785,6 @@
   drizzle_set_byte3(start, con->packet_size);
 
   drizzle_state_pop(con);
+
   return DRIZZLE_RETURN_OK;
 }

=== modified file 'libdrizzle-2.0/row.cc'
--- libdrizzle-2.0/row.cc	2011-11-04 21:06:16 +0000
+++ libdrizzle-2.0/row.cc	2011-11-18 16:11:02 +0000
@@ -69,23 +69,44 @@
                                  drizzle_return_t *ret_ptr)
 {
   size_t total;
-  drizzle_field_t field;
   drizzle_row_t row;
 
+  if (result == NULL)
+  {
+    return drizzle_row_t();
+  }
+
+  drizzle_return_t unused;
+  if (ret_ptr == NULL)
+  {
+    ret_ptr= &unused;
+  }
+
   if (result->row == NULL)
   {
     if (drizzle_row_read(result, ret_ptr) == 0 || *ret_ptr != DRIZZLE_RETURN_OK)
+    {
       return NULL;
-
-    result->row= new drizzle_row_t_type[result->column_count *2];
+    }
+
+    result->row= new (std::nothrow) drizzle_row_t_type[result->column_count *2];
+
+    if (result->row == NULL)
+    {
+      *ret_ptr= DRIZZLE_RETURN_MEMORY;
+      return drizzle_row_t();
+    }
     result->field_sizes= reinterpret_cast<size_t *>(result->row + result->column_count);
   }
 
   while (1)
   {
-    field= drizzle_field_buffer(result, &total, ret_ptr);
+    drizzle_field_t field= drizzle_field_buffer(result, &total, ret_ptr);
     if (*ret_ptr == DRIZZLE_RETURN_ROW_END)
+    {
       break;
+    }
+
     if (*ret_ptr != DRIZZLE_RETURN_OK)
     {
       if (*ret_ptr != DRIZZLE_RETURN_IO_WAIT)

=== modified file 'libdrizzle-2.0/structs.h'
--- libdrizzle-2.0/structs.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/structs.h	2011-11-18 16:11:02 +0000
@@ -69,7 +69,19 @@
 {
 public:
   uint16_t error_code;
-  int options;
+  struct options_t {
+    bool is_allocated;
+    bool is_non_blocking;
+    bool is_free_objects;
+    bool is_assert_dangling;
+
+    options_t() :
+      is_allocated(false),
+      is_non_blocking(false),
+      is_free_objects(false),
+      is_assert_dangling(false)
+    { }
+  } options;
   drizzle_verbose_t verbose;
   uint32_t con_count;
   uint32_t pfds_size;
@@ -92,7 +104,7 @@
 
   drizzle_st() :
     error_code(0),
-    options(DRIZZLE_NONE),
+    options(),
     verbose(DRIZZLE_VERBOSE_ERROR),
     con_count(0),
     pfds_size(0),
@@ -181,7 +193,7 @@
     drizzle_con_uds_st uds;
   } socket;
   uint8_t buffer[DRIZZLE_MAX_BUFFER_SIZE];
-  char db[DRIZZLE_MAX_DB_SIZE];
+  char schema[DRIZZLE_MAX_DB_SIZE];
   char password[DRIZZLE_MAX_PASSWORD_SIZE];
   uint8_t scramble_buffer[DRIZZLE_MAX_SCRAMBLE_SIZE];
   char server_version[DRIZZLE_MAX_SERVER_VERSION_SIZE];
@@ -228,6 +240,7 @@
  */
 class drizzle_query_st
 {
+private:
 public:
   drizzle_st *drizzle;
   drizzle_query_st *next;
@@ -333,7 +346,7 @@
   drizzle_column_st *prev;
   int options;
   char catalog[DRIZZLE_MAX_CATALOG_SIZE];
-  char db[DRIZZLE_MAX_DB_SIZE];
+  char schema[DRIZZLE_MAX_DB_SIZE];
   char table[DRIZZLE_MAX_TABLE_SIZE];
   char orig_table[DRIZZLE_MAX_TABLE_SIZE];
   char name[DRIZZLE_MAX_COLUMN_NAME_SIZE];

=== modified file 'unittests/libdrizzle_test.cc'
--- unittests/libdrizzle_test.cc	2011-11-04 21:06:16 +0000
+++ unittests/libdrizzle_test.cc	2011-11-18 02:03:41 +0000
@@ -31,9 +31,8 @@
 {
   const char* orig= "hello \"world\"\n";
   char out[255];
-  size_t out_len;
 
-  out_len= drizzle_escape_string(out, orig, strlen(orig));
+  ssize_t out_len= drizzle_escape_string(out, sizeof(out), orig, strlen(orig));
 
   BOOST_REQUIRE_EQUAL(17, out_len);
   BOOST_REQUIRE_EQUAL("hello \\\"world\\\"\\n", out);
@@ -43,9 +42,8 @@
 {
   const char orig[6]= {0x00, 0x01, 0x02, 0x03, 0x04, 0x05};
   char out[255];
-  size_t out_len;
 
-  out_len= drizzle_escape_string(out, orig, 6);
+  ssize_t out_len= drizzle_escape_string(out, sizeof(out), orig, 6);
 
   BOOST_REQUIRE_EQUAL(7, out_len);
   BOOST_REQUIRE_EQUAL("\\0\1\2\3\4\5", out);
@@ -55,9 +53,8 @@
 {
   const char* orig= "hello \"world\"\n";
   char out[255];
-  ssize_t out_len;
 
-  out_len= drizzle_safe_escape_string(out, 255, orig, strlen(orig));
+  ssize_t out_len= drizzle_escape_string(out, sizeof(out), orig, strlen(orig));
 
   BOOST_REQUIRE_EQUAL(17, out_len);
   BOOST_REQUIRE_EQUAL("hello \\\"world\\\"\\n", out);
@@ -67,9 +64,8 @@
 {
   const char* orig= "hello \"world\"\n";
   char out[5];
-  ssize_t out_len;
 
-  out_len= drizzle_safe_escape_string(out, 5, orig, strlen(orig));
+  ssize_t out_len= drizzle_escape_string(out, sizeof(out), orig, strlen(orig));
 
   BOOST_REQUIRE_EQUAL(-1, out_len);
 }
@@ -78,9 +74,8 @@
 {
   const unsigned char orig[5]= {0x34, 0x26, 0x80, 0x99, 0xFF};
   char out[255];
-  size_t out_len;
 
-  out_len= drizzle_hex_string(out, (char*) orig, 5);
+  size_t out_len= drizzle_hex_string(out, (char*) orig, 5);
 
   BOOST_REQUIRE_EQUAL(10, out_len);
   BOOST_REQUIRE_EQUAL("34268099FF", out);

